==> p2ray-0.0.2-py3-none-any.whl: P2Ray/utils.py <==
from typing import Optional

import re

from emoji import replace_emoji

import qrcode
from PIL import Image, ImageTk
import tkinter as tk

from multiprocessing import Process

import requests



# ─────────────────────────────────────────────────────────────────────────────
def strip_emojis(
    text: str, 
    replacement: str = "□"
    ) -> str:
    return replace_emoji(text, replacement)

# ─────────────────────────────────────────────────────────────────────────────

def strip_ansi(text: str) -> str:
    return re.sub(r'\x1b\[[0-9;]*m', '', text)

# ─────────────────────────────────────────────────────────────────────────────
def generate_qrcode(uri: str) -> Image.Image:
    qr = qrcode.QRCode(version=1, box_size=10, border=4)
    qr.add_data(uri)
    qr.make(fit=True)
    return qr.make_image(fill_color="black", back_color="white") # type: ignore


def show_image_popup(img: Image.Image, title: str = "QR Code"):
    root = tk.Tk()
    root.title(title)
    root.resizable(False, False)

    tk_img = ImageTk.PhotoImage(img)
    lbl = tk.Label(root, image=tk_img)
    lbl.pack()

    # Center the window
    w, h = img.size
    ws = root.winfo_screenwidth()
    hs = root.winfo_screenheight()
    x = (ws - w) // 2
    y = (hs - h) // 2
    root.geometry(f"{w}x{h}+{x}+{y}")

    # Keep reference to avoid garbage collection
    lbl.image = tk_img # type: ignore

    root.mainloop()
    
    
def _show_qr_process(uri: str, title: str):
    """
    Worker function in a new process. Regenerates the QR and displays it.
    """
    img = generate_qrcode(uri)
    show_image_popup(img, title)
    
    
def show_qr(uri: str, title: str = "QR Code"):
    """
    Spawn a separate process that regenerates and shows the QR code,
    so we never try to pickle a PIL.Image object.
    """
    proc = Process(target=_show_qr_process, args=(uri, title), daemon=True)
    proc.start()

# ─────────────────────────────────────────────────────────────────────────────


    
# utils.py
def test_speed(
    timeout: float = 10.0,
    session: Optional[requests.Session] = None
) -> Optional[float]:
    import time
    test_url = "http://speedtest.tele2.net/5MB.zip"

    if session is None:
        session = requests.Session()

    try:
        start = time.time()
        resp = session.get(test_url, stream=True, timeout=timeout)
        total = 0
        for chunk in resp.iter_content(4096):
            total += len(chunk)
        elapsed = time.time() - start
        mbps = (total * 8 / 1e6) / elapsed
        return mbps
    except Exception:
        return None


# ─────────────────────────────────────────────────────────────────────────────
# Formating Utils
# ─────────────────────────────────────────────────────────────────────────────

CLR_DICT = {
    "reset"  : "\033[0m",
    "gray"   : "\033[90m",
    # Regular Color
    "black"  : "\033[30m",
    "red"    : "\033[31m",
    "green"  : "\033[32m",
    "yellow" : "\033[33m",
    "blue"   : "\033[34m",
    "purple" : "\033[35m",
    "cyan"   : "\033[36m",
    "white"  : "\033[37m",
    # High Intensity (Bright)
    "h black"  : "\033[90m",
    "h red"    : "\033[91m",
    "h green"  : "\033[92m",
    "h yellow" : "\033[93m",
    "h blue"   : "\033[94m",
    "h purple" : "\033[95m",
    "h cyan"   : "\033[96m",
    "h white"  : "\033[97m",   
    # Background
    "b black"  : "\033[40m",
    "b red"    : "\033[41m",
    "b green"  : "\033[42m",
    "b yellow" : "\033[43m",
    "b blue"   : "\033[44m",
    "b purple" : "\033[45m",
    "b cyan"   : "\033[46m",
    "b white"  : "\033[47m",
    # High Intensity Background (Bright)
    "hb black": "\033[100m",  
    "hb red": "\033[101m",    
    "hb green": "\033[102m",
    "hb yellow": "\033[103m", 
    "hb blue": "\033[104m",   
    "hb purple": "\033[105m",
    "hb cyan": "\033[106m",  
    "hb white": "\033[107m",
    # Styles
    "bold": "\033[1m",
    "dim": "\033[2m",
    "italic": "\033[3m",        # Not supported in all terminals
    "underline": "\033[4m",
    "blink": "\033[5m",         # Often ignored in Windows
    "reverse": "\033[7m",       # Swap FG and BG
    "hidden": "\033[8m",        # Not widely supported
    "strikethrough": "\033[9m"  # May not render in CMD
} 


def color(inp: str, color: str) -> str:
    code = CLR_DICT.get(color)
    return f"{code}{inp}\033[0m"

def colorp(inp: str, color: str) -> None:
    code = CLR_DICT.get(color)
    print(f"{code}{inp}\033[0m")

def underline(text: str) -> str:
    return f"\033[4m{text}\033[24m"

# ─────────────────────────────────────────────────────────────────────────────
def styled_header(
    text: str,
    alias: str,
    fg_color: str = "h cyan"
) -> str:
    """
    Return `text` in bright‐cyan, underlining each character
    in `alias` in sequence as they appear (case‐insensitive).
    """
    alias_chars = list(alias.lower())
    ai = 0  # index into alias_chars
    out: list[str] = []

    for ch in text:
        if ai < len(alias_chars) and ch.lower() == alias_chars[ai]:
            # Underline+color this character
            # Combine CSI codes: 4 for underline, plus fg code
            code = CLR_DICT[fg_color][2:-1]  # e.g. "96"
            out.append(f"\033[4;{code}m{ch}\033[0m")
            ai += 1
        else:
            # Just color it
            out.append(color(ch, fg_color))

    return "".join(out)

# ─────────────────────────────────────────────────────────────────────────────
def press_enter(
    message: str = "Press Enter to continue…"
    ) -> None:
    input(color(f"\n{message}", "h blue"))

==> p2ray-0.0.2.1-py3-none-any.whl: P2Ray/utils.py <==
from typing import Optional

import re

from emoji import replace_emoji

import qrcode
from PIL import Image, ImageTk
import tkinter as tk

from multiprocessing import Process

import requests



# ─────────────────────────────────────────────────────────────────────────────
def strip_emojis(
    text: str,
    replacement: str = "□"
    ) -> str:
    return replace_emoji(text, replacement)

# ─────────────────────────────────────────────────────────────────────────────

def strip_ansi(text: str) -> str:
    return re.sub(r'\x1b\[[0-9;]*m', '', text)

# ─────────────────────────────────────────────────────────────────────────────
def generate_qrcode(uri: str) -> Image.Image:
    qr = qrcode.QRCode(version=1, box_size=10, border=4)
    qr.add_data(uri)
    qr.make(fit=True)
    return qr.make_image(fill_color="black", back_color="white") # type: ignore


def show_image_popup(img: Image.Image, title: str = "QR Code"):
    root = tk.Tk()
    root.title(title)
    root.resizable(False, False)

    tk_img = ImageTk.PhotoImage(img)
    lbl = tk.Label(root, image=tk_img)
    lbl.pack()

    # Center the window
    w, h = img.size
    ws = root.winfo_screenwidth()
    hs = root.winfo_screenheight()
    x = (ws - w) // 2
    y = (hs - h) // 2
    root.geometry(f"{w}x{h}+{x}+{y}")

    # Keep reference to avoid garbage collection
    lbl.image = tk_img # type: ignore

    root.mainloop()


def _show_qr_process(uri: str, title: str):
    """
    Worker function in a new process. Regenerates the QR and displays it.
    """
    img = generate_qrcode(uri)
    show_image_popup(img, title)


def show_qr(uri: str, title: str = "QR Code"):
    """
    Spawn a separate process that regenerates and shows the QR code,
    so we never try to pickle a PIL.Image object.
    """
    proc = Process(target=_show_qr_process, args=(uri, title), daemon=True)
    proc.start()

# ─────────────────────────────────────────────────────────────────────────────



# utils.py
def test_speed(
    timeout: float = 10.0,
    session: Optional[requests.Session] = None
) -> Optional[float]:
    import time
    test_url = "http://speedtest.tele2.net/5MB.zip"

    if session is None:
        session = requests.Session()

    try:
        start = time.time()
        resp = session.get(test_url, stream=True, timeout=timeout)
        total = 0
        for chunk in resp.iter_content(4096):
            total += len(chunk)
        elapsed = time.time() - start
        mbps = (total * 8 / 1e6) / elapsed
        return mbps
    except Exception:
        return None


# ─────────────────────────────────────────────────────────────────────────────
# Formating Utils
# ─────────────────────────────────────────────────────────────────────────────

CLR_DICT = {
    "reset"  : "\033[0m",
    "gray"   : "\033[90m",
    # Regular Color
    "black"  : "\033[30m",
    "red"    : "\033[31m",
    "green"  : "\033[32m",
    "yellow" : "\033[33m",
    "blue"   : "\033[34m",
    "purple" : "\033[35m",
    "cyan"   : "\033[36m",
    "white"  : "\033[37m",
    # High Intensity (Bright)
    "h black"  : "\033[90m",
    "h red"    : "\033[91m",
    "h green"  : "\033[92m",
    "h yellow" : "\033[93m",
    "h blue"   : "\033[94m",
    "h purple" : "\033[95m",
    "h cyan"   : "\033[96m",
    "h white"  : "\033[97m",
    # Background
    "b black"  : "\033[40m",
    "b red"    : "\033[41m",
    "b green"  : "\033[42m",
    "b yellow" : "\033[43m",
    "b blue"   : "\033[44m",
    "b purple" : "\033[45m",
    "b cyan"   : "\033[46m",
    "b white"  : "\033[47m",
    # High Intensity Background (Bright)
    "hb black": "\033[100m",
    "hb red": "\033[101m",
    "hb green": "\033[102m",
    "hb yellow": "\033[103m",
    "hb blue": "\033[104m",
    "hb purple": "\033[105m",
    "hb cyan": "\033[106m",
    "hb white": "\033[107m",
    # Styles
    "bold": "\033[1m",
    "dim": "\033[2m",
    "italic": "\033[3m",        # Not supported in all terminals
    "underline": "\033[4m",
    "blink": "\033[5m",         # Often ignored in Windows
    "reverse": "\033[7m",       # Swap FG and BG
    "hidden": "\033[8m",        # Not widely supported
    "strikethrough": "\033[9m"  # May not render in CMD
}


def color(inp: str, color: str) -> str:
    code = CLR_DICT.get(color)
    return f"{code}{inp}\033[0m"

def colorp(inp: str, color: str) -> None:
    code = CLR_DICT.get(color)
    print(f"{code}{inp}\033[0m")

def underline(text: str) -> str:
    return f"\033[4m{text}\033[24m"

# ─────────────────────────────────────────────────────────────────────────────
def styled_header(
    text: str,
    alias: str,
    fg_color: str = "h cyan"
) -> str:
    """
    Return `text` in bright-cyan, underlining each character
    in `alias` in sequence as they appear (case-insensitive).
    """
    alias_chars = list(alias.lower())
    ai = 0  # index into alias_chars
    out: list[str] = []

    for ch in text:
        if ai < len(alias_chars) and ch.lower() == alias_chars[ai]:
            # Underline+color this character
            # Combine CSI codes: 4 for underline, plus fg code
            code = CLR_DICT[fg_color][2:-1]  # e.g. "96"
            out.append(f"\033[4;{code}m{ch}\033[0m")
            ai += 1
        else:
            # Just color it
            out.append(color(ch, fg_color))

    return "".join(out)

# ─────────────────────────────────────────────────────────────────────────────
def press_enter(
    message: str = "Press Enter to continue…"
    ) -> None:
    input(color(f"\n{message}", "h blue"))
